function [x, acceptances] = positiveNormal(n)
%POSITIVENORMAL returns a sample of size n from the positive normal
% distribution sampled with the rejection method.
% the proposal distribution is taken to be exp(1).

x = zeros(1,n);
acceptances = 0;
% define the denisities
f = @(x) sqrt(2/pi) * exp(-0.5*x^2);
g = @(x) exp(-x);

% we have found the maximum to be 
c = sqrt(2*exp(1)/pi);
cg = @(x) c.*exp(-x);
% start sampling
for i = 1:1:n
    flag = 1;
    while flag
        u = rand;
        y = rndexp(1, 1);
        if (u <= f(y) / (c * g(y)))
            x(i) = y;
            flag = 0;
        end
        acceptances = acceptances+1;
    end
end

h = histogram(x,50,'normalization','pdf');
set(h,'facecolor',[0.8 .8 1], 'FaceAlpha',1)
hold on
[x,y] = fplot(f,[0,5]);
plot(x,y,'r-','LineWidth',2)
[x,y]=fplot(cg, [0,5]);
plot(x,y,'--k','LineWidth',2)
l=legend('Samples','$f(x)$','$c\cdot g(x)$','location','northeast');
set(l,'interpreter','latex')
ylim([0,1.4])

function e = rndexp(lambda, k)
e = - log(rand(1,k))./lambda;



